# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.23.2~be1064a',
    built_at='2025-10-21 21:01:43Z',
    sha='be1064abdbdb13f066f277486d1dee1d58d8cc9e',
    branch='HEAD',
    tag='v4.23.2',
)
